.. include:: tutorials/README.rst

.. toctree::
    :maxdepth: 1

    tutorials/t01
    tutorials/t02
    tutorials/t03
    tutorials/t04
    tutorials/t05
    tutorials/t06
    tutorials/t07
    tutorials/t08
    tutorials/t09
    tutorials/t10
